@@ -6,7 +6,7 @@
 #'   power = 1, bp = NULL, osci = FALSE, wl = 512, xl = 1, picsize = 1, res = 100, 
 #'   flim = c(0,22), ls = FALSE, sxrow = 10, rows = 10, mindur = NULL, maxdur = 
 #'   NULL, redo = FALSE, img = TRUE, it = "jpeg", set = FALSE, flist = NULL, smadj = NULL,
-#'   parallel = FALSE)
+#'   parallel = 1)
 #' @param X Data frame with results from \code{\link{manualoc}} function or any data frame with columns
 #' for sound file name (sound.files), selection number (selec), and start and end time of signal
 #' (start and end). 
@@ -71,8 +71,11 @@
 #' smoothing through ssmooth generates a predictable deviation from the actual start and end positions of the signals, 
 #' determined by the threshold and ssmooth values. This deviation is more obvious (and problematic) when the 
 #' increase and decrease in amplitude at the start and end of the signal (respectively) is not gradual. Ignored if ssmooth is \code{NULL}.
-#' @param parallel Either logical or numeric. Controls wehther parallel computing is applied.
-#'  If \code{TRUE} 2 cores are employed. If numeric, it specifies the number of cores to be used.  
+#' @param parallel Numeric. Controls whether parallel computing is applied.
+#'  It specifies the number of cores to be used. Default is 1 (e.i. no parallel computing).
+#'   windows OS users need to install warbleR from github to run parallel.
+#'   Note that creating images is not compatible with parallel computing 
+#'   (parallel > 1) in OSX (mac).   
 #' @return Image files with spectrograms showing the start and end of the detected signals. It 
 #'   also returns a data frame containing the start and end of each signal by 
 #'   sound file and selection number.
@@ -89,8 +92,7 @@
 #' @examples
 #' \dontrun{
 #' # First create empty folder
-#' dir.create(file.path(getwd(),"temp"))
-#' setwd(file.path(getwd(),"temp"))
+#' setwd(tempdir())
 #' 
 #' data(list = c("Phae.long1", "Phae.long2", "Phae.long3", "Phae.long4"))
 #' writeWave(Phae.long1,"Phae.long1.wav")
@@ -109,19 +111,16 @@
 #' 
 #' #check this folder!!
 #' getwd()
-#' 
-#' #remove example directory
-#' unlink(getwd(),recursive = TRUE)
 #' }
 #' 
-#' @author Marcelo Araya-Salas (\url{http://marceloarayasalas.weebly.com/}). Implements a
+#' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu}). Implements a
 #' modified version of the timer function from seewave. 
 
 autodetec<-function(X= NULL, threshold=15, envt="abs", ssmooth = NULL, msmooth = NULL, power = 1, 
                     bp = NULL, osci = FALSE, wl = 512, xl = 1, picsize = 1, res = 100, flim = c(0,22), 
                     ls = FALSE, sxrow = 10, rows = 10, mindur = NULL, maxdur = NULL, redo = FALSE, 
-                    img = TRUE, it = "jpeg", set = FALSE, flist = NULL, smadj = NULL, parallel = FALSE){
-
+                    img = TRUE, it = "jpeg", set = FALSE, flist = NULL, smadj = NULL, parallel = 1){
+  
   #if bp is not vector or length!=2 stop
   if(!is.null(bp))
   {if(!is.vector(bp)) stop("'bp' must be a numeric vector of length 2") else{
@@ -176,6 +175,9 @@ autodetec<-function(X= NULL, threshold=15, envt="abs", ssmooth = NULL, msmooth =
   if(is.null(threshold))  stop("'threshold' must be a numeric vector of length 1") else {
     if(!is.vector(threshold)) stop("'threshold' must be a numeric vector of length 1") else{
       if(!length(threshold) == 1) stop("'threshold' must be a numeric vector of length 1")}}  
+  #if parallel is not numeric
+  if(!is.numeric(parallel)) stop("'parallel' must be a numeric vector of length 1") 
+  if(any(!(parallel %% 1 == 0),parallel < 1)) stop("'parallel' should be a positive integer")
   
   #if it argument is not "jpeg" or "tiff" 
   if(!any(it == "jpeg", it == "tiff")) stop(paste("Image type", it, "not allowed"))  
@@ -197,14 +199,28 @@ autodetec<-function(X= NULL, threshold=15, envt="abs", ssmooth = NULL, msmooth =
   if(!is.null(smadj)) if(!any(smadj == "start", smadj == "end", smadj == "both")) 
     stop(paste("smooth adjustment", smadj, "not allowed"))  
   
+  #if parallel T and img T
+  if(all(parallel > 1, img, !Sys.info()[1] %in% c("Linux","Windows"))) {
+    parallel <- 1
+    cat("creating images is not compatible with parallel computing (parallel > 1) in OSX (mac)")
+  }
+  
   #if parallel was called
-  if (parallel) {lapp <- function(X, FUN) parallel::mclapply(X, 
-     FUN, mc.cores = 2)} else    if(is.numeric(parallel)) lapp <- function(X, FUN) parallel::mclapply(X, 
-     FUN, mc.cores = parallel) else lapp <- pbapply::pblapply
-                                                                                                                                                              
+      #if on windows you need parallelsugar package
+   if(parallel > 1)
+  { 
+#      options(warn = -1)
+#      
+#        
+#        if(Sys.info()[1] == "Windows"){ 
+#       cat 
+#       lapp <- pbapply::pblapply} else 
+        lapp <- function(X, FUN) parallel::mclapply(X, FUN, mc.cores = parallel)} else lapp <- pbapply::pblapply
+      
+      options(warn = 0)
+      
   if(!is.null(X)){
     
-    
     #check if all columns are found
     if(any(!(c("sound.files", "selec", "start", "end") %in% colnames(X)))) 
       stop(paste(paste(c("sound.files", "selec", "start", "end")[!(c("sound.files", "selec", 
@@ -224,7 +240,7 @@ autodetec<-function(X= NULL, threshold=15, envt="abs", ssmooth = NULL, msmooth =
     #return warning if not all sound files were found
     fs <- list.files(path = getwd(), pattern = ".wav$", ignore.case = TRUE)
     if(length(unique(X$sound.files[(X$sound.files %in% fs)])) != length(unique(X$sound.files))) 
-      message(paste(length(unique(X$sound.files))-length(unique(X$sound.files[(X$sound.files %in% fs)])), 
+      cat(paste(length(unique(X$sound.files))-length(unique(X$sound.files[(X$sound.files %in% fs)])), 
                     ".wav file(s) not found"))
     
     #count number of sound files in working directory and if 0 stop
@@ -243,8 +259,8 @@ autodetec<-function(X= NULL, threshold=15, envt="abs", ssmooth = NULL, msmooth =
       if(nrow(X) == 0) stop("All selections have been analyzed (redo = F)") 
     }    
     
-    if(!parallel) {if(!ls & img) message("Detecting signals in sound files and producing spectrogram:") else 
-      message("Detecting signals in sound files:")}
+    if(parallel == 1) {if(!ls & img) cat("Detecting signals in sound files and producing spectrogram:") else 
+      cat("Detecting signals in sound files:")}
     
     ad<-lapp(1:nrow(X),function(i)
   {
@@ -384,7 +400,7 @@ if(length(files) == 0) stop("All files have been analyzed (redo = F)")
     }
     }  
     
-    if(!parallel)  message("Detecting signals in sound files:")
+    if(parallel == 1)  cat("Detecting signals in sound files:")
     
     ad<-lapp(1:length(files),function(i)
     {
@@ -471,7 +487,7 @@ results<-rbind(results,data.frame(sound.files =  files[v], selec = 1,start=ad[[v
   
   #long spectrograms
 if(any(ls,is.null(X)) & img) {
-  if(!parallel) message("Producing long spectrogram:")
+  if(parallel == 1) cat("Producing long spectrogram:")
   
   collev = seq(-40, 0, 1)  
   manualoc = data.frame(results,sel.comment=NA)
