@@ -7,7 +7,7 @@
 #'   c(0, 0, 0, 0), picsize = 1, res = 100, cexlab = 1, title = TRUE, propwidth = FALSE, 
 #'   xl = 1, gr = FALSE, sc = FALSE, bp = c(0, 22), cex = 1, 
 #'   threshold = 15, col = "dodgerblue", pch = 16,  mar = 0.05, 
-#'   lpos = "topright", it = "jpeg", img = TRUE, parallel = FALSE)
+#'   lpos = "topright", it = "jpeg", img = TRUE, parallel = 1)
 #' @param  X Data frame with results containing columns for sound file name (sound.files), 
 #' selection number (selec), and start and end time of signal (start and end).
 #' The ouptut of \code{\link{manualoc}} or \code{\link{autodetec}} can be used as the input data frame. 
@@ -65,9 +65,11 @@
 #' @param it A character vector of length 1 giving the image type to be used. Currently only
 #' "tiff" and "jpeg" are admitted. Default is "jpeg".
 #' @param img Logical argument. If \code{FALSE}, image files are not produced. Default is \code{TRUE}.
-#' @param parallel Either logical or numeric. Controls wehther parallel computing is applied.
-#'  If \code{TRUE} 2 cores are employed. If numeric, it specifies the number of cores to be used. 
-#'  Not available for windows OS. 
+#' @param parallel Numeric. Controls whether parallel computing is applied.
+#'  It specifies the number of cores to be used. Default is 1 (e.i. no parallel computing).
+#'   windows OS users need to install \code{warbleR} from github to run parallel.
+#'   Note that creating images is not compatible with parallel computing 
+#'   (parallel > 1) in OSX (mac).   
 #' @return A data frame with the dominant frequency values measured across the signals. If img is 
 #' \code{FALSE} it also produces image files with the spectrograms of the signals listed in the 
 #' input data frame showing the location of the dominant frequencies.
@@ -94,14 +96,14 @@
 #' dfts(manualoc.df, length.out = 30, flim = c(1, 12), picsize = 2, res = 100, bp = c(2, 9))
 #' 
 #' }
-#' @author Marcelo Araya-Salas (\url{http://marceloarayasalas.weebly.com/})
+#' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu})
 
 
 dfts <- function(X, wl = 512, flim = c(0, 22), length.out = 20, wn = "hanning", pal = reverse.gray.colors.2, ovlp = 70, 
                        inner.mar = c(5,4,4,2), outer.mar = c(0,0,0,0), picsize = 1, res = 100, cexlab = 1,
                        title = TRUE, propwidth = FALSE, xl = 1, gr = FALSE, sc = FALSE, 
                        bp = c(0, 22), cex = 1, threshold = 15, col = "dodgerblue",pch = 16,
-                       mar = 0.05, lpos = "topright", it = "jpeg", img = TRUE, parallel = FALSE){     
+                       mar = 0.05, lpos = "topright", it = "jpeg", img = TRUE, parallel = 1){     
   
   if(class(X) == "data.frame") {if(all(c("sound.files", "selec", 
                                          "start", "end") %in% colnames(X))) 
@@ -134,10 +136,14 @@ dfts <- function(X, wl = 512, flim = c(0, 22), length.out = 20, wn = "hanning",
   #if it argument is not "jpeg" or "tiff" 
   if(!any(it == "jpeg", it == "tiff")) stop(paste("Image type", it, "not allowed"))  
   
+  # If length.out is not numeric
+  if(!is.numeric(length.out)) stop("'length.out' must be a numeric vector of length 1") 
+  if(any(!(length.out %% 1 == 0),length.out < 1)) stop("'length.out' should be a positive integer")
+  
   #return warning if not all sound files were found
   recs.wd <- list.files(path = getwd(), pattern = ".wav$", ignore.case = T)
   if(length(unique(sound.files[(sound.files %in% recs.wd)])) != length(unique(sound.files))) 
-    message(paste(length(unique(sound.files))-length(unique(sound.files[(sound.files %in% recs.wd)])), 
+    cat(paste(length(unique(sound.files))-length(unique(sound.files[(sound.files %in% recs.wd)])), 
                   ".wav file(s) not found"))
   
   #count number of sound files in working directory and if 0 stop
@@ -151,27 +157,60 @@ dfts <- function(X, wl = 512, flim = c(0, 22), length.out = 20, wn = "hanning",
     sound.files <- sound.files[d]
   }
   
-  #if parallel was called
-  if (parallel) {lapp <- function(X, FUN) parallel::mclapply(X, 
-        FUN, mc.cores = 2)} else    
-            if(is.numeric(parallel)) lapp <- function(X, FUN) parallel::mclapply(X, 
-                FUN, mc.cores = parallel) else lapp <- pbapply::pblapply
   
- if(!parallel) {if(img) message("Creating spectrograms overlaid with dominant frequency measurements:") else
-    message("Calculating dominant frequency measurements:")}  
+  
+  #if parallel is not numeric
+  if(!is.numeric(parallel)) stop("'parallel' must be a numeric vector of length 1") 
+  if(any(!(parallel %% 1 == 0),parallel < 1)) stop("'parallel' should be a positive integer")
+  
+  #if parallel
+  if(all(parallel > 1, img, !Sys.info()[1] %in% c("Linux","Windows"))) {
+    parallel <- 1
+    cat("creating images is not compatible with parallel computing (parallel > 1) in OSX (mac)")
+  }
+  
+  #if on windows you need parallelsugar package
+  if(parallel > 1)
+  { 
+    #      options(warn = -1)
+    #      
+    #        
+    #        if(Sys.info()[1] == "Windows"){ 
+    #       cat 
+    #       lapp <- pbapply::pblapply} else 
+    lapp <- function(X, FUN) parallel::mclapply(X, FUN, mc.cores = parallel)} else lapp <- pbapply::pblapply
+  
+  options(warn = 0)
+  
+ if(parallel == 1) {if(img) cat("Creating spectrograms overlaid with dominant frequency measurements:") else
+    cat("Calculating dominant frequency measurements:")}  
   
   lst<-lapp(1:length(sound.files), function(i){
     
-    r <- tuneR::readWave(file.path(getwd(), sound.files[i]))
-    
-    f <- r@samp.rate
+    # Read sound files to get sample rate and length
+    r <- tuneR::readWave(file.path(getwd(), sound.files[i]), header = TRUE)
+    f <- r$sample.rate
     t <- c(start[i] - mar, end[i] + mar)
-    cex <- cex
- 
+    
+    #reset coordinates of signals 
+    mar1 <- start[i]-t[1]
+    mar2 <- mar1 + end[i] - start[i]
+    
+    if (t[1] < 0) { t[2] <- abs(t[1]) + t[2] 
+    mar1 <- mar1  + t[1]
+    mar2 <- mar2  + t[1]
+    t[1] <- 0
+    }
+    
+    if(t[2] > r$samples/f) t[2] <- r$samples/f
+  
     b<- bp 
     if(!is.null(b)) {if(b[2] > ceiling(f/2000) - 1) b[2] <- ceiling(f/2000) - 1 
     b <- b * 1000}
     
+    
+      r <- tuneR::readWave(as.character(sound.files[i]), from = t[1], to = t[2], units = "seconds")
+    
     if(img) {
       #in case bp its higher than can be due to sampling rate
     
@@ -199,7 +238,7 @@ dfts <- function(X, wl = 512, flim = c(0, 22), length.out = 20, wn = "hanning",
     # Generate spectrogram using seewave
     seewave::spectro(r, f = f, wl = wl, ovlp = 70, collevels = seq(-40, 0, 0.5),
                      wn = "hanning", widths = wts, palette = pal, grid = gr, scale = sc, collab = "black", 
-                     cexlab = cexlab, cex.axis = 0.5*picsize, tlim = t, flim = fl, tlab = "Time (s)", 
+                     cexlab = cexlab, cex.axis = 0.5*picsize, flim = fl, tlab = "Time (s)", 
                      flab = "Frequency (kHz)", alab = "")
     
     if(title){
@@ -210,13 +249,13 @@ dfts <- function(X, wl = 512, flim = c(0, 22), length.out = 20, wn = "hanning",
     
     # Plot dominant frequency at each time point     
     dfreq <- seewave::dfreq(r, f = f, wl = wl, plot = FALSE, ovlp = ovlp, bandpass = b, fftw = TRUE, 
-                            threshold = threshold, tlim=c(start[i],end[i]))
+                            threshold = threshold, tlim = c(mar1, mar2))
     
     apdom<-approx(dfreq[,1], dfreq[,2], n =length.out, method = "linear")
     
     
-    points(apdom$x+start[i], apdom$y, col = col, cex = cex, pch = pch) 
-    abline(v = c(end[i],start[i]), col= "red", lty = "dashed")
+    points(apdom$x+mar1, apdom$y, col = col, cex = cex, pch = pch) 
+    abline(v = c(mar1, mar2), col= "red", lty = "dashed")
     
     # Legend coordinates can be uniquely adjusted 
     legend(lpos, legend = c("Dfreq"),
@@ -225,7 +264,7 @@ dfts <- function(X, wl = 512, flim = c(0, 22), length.out = 20, wn = "hanning",
     dev.off()
     } else 
       dfreq <- seewave::dfreq(r, f = f, wl = wl, plot = FALSE, ovlp = 99, bandpass = b, fftw = TRUE, 
-                              threshold = threshold, tlim=c(start[i],end[i]))
+                              threshold = threshold, tlim = c(mar1, mar2))
     
     apdom<-approx(dfreq[,1], dfreq[,2], n =length.out, method = "linear")
     
