@@ -4,9 +4,9 @@
 #' will be measured by \code{\link{sig2noise}}.
 #' @usage snrspecs(X, wl = 512, flim = c(0, 22), wn = "hanning", pal =
 #'   reverse.gray.colors.2, ovlp = 70, inner.mar = c(5, 4, 4, 2), outer.mar =
-#'   c(0, 0, 0, 0), picsize = 1, res = 100, cexlab = 1, title = TRUE, trel =
-#'   FALSE, propwidth = FALSE, xl=1, osci = FALSE, gr = FALSE, sc = FALSE, mar =
-#'   0.2, snrmar = 0.1, it = "jpeg", parallel = FALSE)
+#'   c(0, 0, 0, 0), picsize = 1, res = 100, cexlab = 1, title = TRUE, 
+#'   propwidth= FALSE, xl=1, osci = FALSE, gr = FALSE, sc = FALSE, mar =
+#'   0.2, snrmar = 0.1, it = "jpeg", parallel = 1)
 #' @param  X Data frame with results from \code{\link{manualoc}} or any data frame with columns
 #' for sound file name (sound.files), selection number (selec), and start and end time of signal
 #' (start and end). 
@@ -35,8 +35,6 @@
 #'   labels. See \code{\link[seewave]{spectro}}.
 #' @param title Logical argument to add a title to individual spectrograms. 
 #'   Default is \code{TRUE}.
-#' @param trel Logical argument to add a time axis scale relative to the wave. 
-#'   Default is \code{FALSE}.
 #' @param propwidth Logical argument to scale the width of spectrogram 
 #'   proportionally to duration of the selected call. Default is \code{FALSE}.
 #' @param xl Numeric vector of length 1, a constant by which to scale 
@@ -48,13 +46,15 @@
 #'   \code{FALSE}.
 #' @param mar Numeric vector of length 1. Specifies the margins adjacent to the 
 #' start and end points of the selections to define spectrogram limits. Default is 0.2.
-#' @param snrmar Numeric vector of length 1. Specifies the margins adjacent to the start and end 
+#' @param snrmar Numeric vector of length 1. Specifies the margins adjacent to the start and end
 #' points of the selections where noise will be measured. Default is 0.1.
 #' @param it A character vector of length 1 giving the image type to be used. Currently only
 #' "tiff" and "jpeg" are admitted. Default is "jpeg".
-#' @param parallel Either logical or numeric. Controls wehther parallel computing is applied.
-#'  If \code{TRUE} 2 cores are employed. If numeric, it specifies the number of cores to be used. 
-#'  Not available for windows OS. 
+#' @param parallel Numeric. Controls whether parallel computing is applied.
+#' It specifies the number of cores to be used. Default is 1 (e.i. no parallel computing).
+#' For windows OS the \code{warbleR} from github to run parallel. 
+#'   Note that creating images is not compatible with parallel computing 
+#'   (parallel > 1) in OSX (mac).   
 #' @return Spectrograms per selection marked with margins where background noise will be measured.
 #' @family spectrogram creators
 #' @seealso \code{\link{trackfreqs}} for creating spectrograms to visualize 
@@ -100,13 +100,13 @@
 #' #remove example directory
 #' unlink(getwd(),recursive = TRUE)
 #' }
-#' @author Marcelo Araya-Salas (\url{http://marceloarayasalas.weebly.com/}) and Grace Smith Vidaurre
+#' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu}) and Grace Smith Vidaurre
 #' @source \url{https://en.wikipedia.org/wiki/Signal-to-noise_ratio}
 
 snrspecs <- function(X, wl = 512, flim = c(0, 22), wn = "hanning", pal = reverse.gray.colors.2, ovlp = 70,
                      inner.mar = c(5,4,4,2), outer.mar = c(0,0,0,0), picsize = 1, res = 100,
-                     cexlab = 1, title = TRUE, trel = FALSE, propwidth = FALSE, xl = 1, osci = FALSE, 
-                     gr = FALSE, sc = FALSE, mar = 0.2, snrmar = 0.1, it = "jpeg", parallel = FALSE){
+                     cexlab = 1, title = TRUE, propwidth = FALSE, xl = 1, osci = FALSE, 
+                     gr = FALSE, sc = FALSE, mar = 0.2, snrmar = 0.1, it = "jpeg", parallel = 1){
 
   if(class(X) == "data.frame") {if(all(c("sound.files", "selec", 
                                          "start", "end") %in% colnames(X))){
@@ -138,7 +138,7 @@ snrspecs <- function(X, wl = 512, flim = c(0, 22), wn = "hanning", pal = reverse
   #return warning if not all sound files were found
   fs <- list.files(path = getwd(), pattern = ".wav$", ignore.case = TRUE)
   if(length(unique(sound.files[(sound.files %in% fs)])) != length(unique(sound.files))) 
-    message(paste(length(unique(sound.files))-length(unique(sound.files[(sound.files %in% fs)])), 
+    cat(paste(length(unique(sound.files))-length(unique(sound.files[(sound.files %in% fs)])), 
                   ".wav file(s) not found"))
   
   #count number of sound files in working directory and if 0 stop
@@ -152,33 +152,63 @@ snrspecs <- function(X, wl = 512, flim = c(0, 22), wn = "hanning", pal = reverse
     sound.files <- sound.files[d]
   }
   
-  #if parallel was called
-  if (parallel) {lapp <- function(X, FUN) parallel::mclapply(X, 
-        FUN, mc.cores = 2)} else    
-          if(is.numeric(parallel)) lapp <- function(X, FUN) parallel::mclapply(X, 
-              FUN, mc.cores = parallel) else lapp <- pbapply::pblapply
+  # If parallel is not numeric
+  if(!is.numeric(parallel)) stop("'parallel' must be a numeric vector of length 1") 
+  if(any(!(parallel %% 1 == 0),parallel < 1)) stop("'parallel' should be a positive integer")
   
+  #if parallel in OSX
+  if(all(parallel > 1, !Sys.info()[1] %in% c("Linux","Windows"))) {
+    parallel <- 1
+    cat("creating images is not compatible with parallel computing (parallel > 1) in OSX (mac)")
+  }
   
-  if(!parallel) message("Creating spectrograms with signal and noise margins to be used in sig2noise():")
+  #if on windows you need parallelsugar package
+  if(parallel > 1)
+  { 
+    #      options(warn = -1)
+    #      
+    #        
+    #        if(Sys.info()[1] == "Windows"){ 
+    #       cat 
+    #       lapp <- pbapply::pblapply} else 
+    lapp <- function(X, FUN) parallel::mclapply(X, FUN, mc.cores = parallel)} else lapp <- pbapply::pblapply
+  
+  options(warn = 0)
+  
+  if(parallel == 1) cat("Creating spectrograms with signal and noise margins to be used in sig2noise():")
   invisible(lapp(1:length(sound.files), function(i){
     
     r <- tuneR::readWave(file.path(getwd(), sound.files[i])) 
     f <- r@samp.rate
     
+    # Read sound files to get sample rate and length
+    r <- tuneR::readWave(file.path(getwd(), sound.files[i]), header = TRUE)
+    f <- r$sample.rate
+    
     fl<- flim #in case flim its higher than can be due to sampling rate
     if(fl[2] > ceiling(f/2000) - 1) fl[2] <- ceiling(f/2000) - 1 
     
-    # Correct start and end time if is smaller than 0 or higer than length of rec
-    st <- start[i] - mar
-    en <- end[i] + mar
-    if (st < 0) st <- 0
-    if (en > length(r@left)/r@samp.rate) en <- length(r@left)/r@samp.rate
-    
-    t <- c(st, en)
     
     # Set mar equals to snrmar if is smaller
     if(mar < snrmar) mar <- snrmar
+    
+    # Correct start and end time if is smaller than 0 or higher than length of rec
+    st <- start[i] - mar
+    en <- end[i] + mar
+    mar1 <- mar
+    mar2 <- mar1 + end[i] - start[i]
+    
+    if (st < 0)  {
+      mar1 <- mar1  + st
+      mar2 <- mar2  + st
+      st <- 0
+      }
+  
+    if(en > r$samples/f) en <- r$samples/f
 
+    r <- tuneR::readWave(file.path(getwd(), sound.files[i]), from = st, to = en, units = "seconds")
+    
+    
 # Spectrogram width can be proportional to signal duration
     if(propwidth == TRUE){
       if(it == "tiff")  tiff(filename = paste(sound.files[i],"-", selec[i], "-", "snr", ".tiff", sep = ""), 
@@ -210,49 +240,29 @@ snrspecs <- function(X, wl = 512, flim = c(0, 22), wn = "hanning", pal = reverse
     seewave::spectro(r, f = f, wl = wl, ovlp = ovlp, collevels = seq(-40, 0, 0.5), heights = hts,
             wn = "hanning", widths = wts, palette = pal, osc = osci, grid = gr, scale = sc, 
             collab = "black", cexlab = cexlab, cex.axis = 0.5*picsize, tlab = "Time (s)", 
-            flab = "Frequency (kHz)", tlim = t, flim = fl, alab = "", trel = trel)
+            flab = "Frequency (kHz)", flim = fl, alab = "", trel = FALSE)
     
     if(title){
-      
       title(paste(sound.files[i], "-", selec[i], "-", "snr", sep = ""), cex.main = cexlab)
-      
     }
     
     # Add lines to visualize signal
-    if(trel)
-    abline(v = c(start[i], end[i]), col = "red", lwd = 1.5, lty = "dashed") else {
-      abline(v = c(mar, end[i] - start[i] + mar), col = "red", lwd = 1.5, lty = "dashed")
-    }
+    abline(v = c(mar1, mar2), col = "red", lwd = 1.5, lty = "dashed") 
     
     # Add lines to visualize where noise will be measured in sig2noise
-    if(trel)
-    abline(v = c(start[i] - snrmar, end[i] + snrmar), col = "red", lwd = 1.5, lty = "dashed") else{
-    abline(v = c(mar - snrmar, end[i] - start[i] + mar + snrmar), col = "red", lwd = 1.5, lty = "dashed")  
-  }
-   
+    abline(v = c(mar1 - snrmar, mar2 + snrmar), col = "red", lwd = 1.5, lty = "dashed") 
+    
     #add arrows/text indicating noise position
-    if(trel) 
-    {arrows(x0 =start[i] - snrmar, y0 = fl[1]+fl[2]/6, x1 = start[i], y1 = fl[1]+fl[2]/6, code = 3, 
+    arrows(x0 =mar1 - snrmar, y0 = fl[1]+fl[2]/6, x1 = mar1, y1 = fl[1]+fl[2]/6, code = 3, 
            col = "red", lty = "solid", lwd = 2, angle = 60)        
   
-    arrows(x0 =end[i] + snrmar, y0 = fl[1]+fl[2]/6, x1 = end[i], y1 = fl[1]+fl[2]/6, code = 3, 
+    arrows(x0 =mar2 + snrmar, y0 = fl[1]+fl[2]/6, x1 = mar2, y1 = fl[1]+fl[2]/6, code = 3, 
            col = "red", lty = "solid", lwd = 2, angle = 60)        
     
-    text(x = start[i] - (snrmar * 0.5), y = fl[1]+fl[2]/4, labels = "Noise", col = "red",pos = 3)
+    text(x = mar1 - (snrmar * 0.5), y = fl[1]+fl[2]/4, labels = "Noise", col = "red",pos = 3)
+    
+    text(x = mar2 + (snrmar * 0.5), y = fl[1]+fl[2]/4, labels = "Noise", col = "red",pos = 3) 
     
-    text(x = end[i] + (snrmar * 0.5), y = fl[1]+fl[2]/4, labels = "Noise", col = "red",pos = 3)} else {
-      
-    arrows(x0 =mar - snrmar, y0 = fl[1]+fl[2]/6, x1 = mar, y1 = fl[1]+fl[2]/6, code = 3, 
-    col = "red", lty = "solid", lwd = 2, angle = 60)        
-      
-    arrows(x0 =end[i] - start[i] + mar + snrmar, y0 = fl[1]+fl[2]/6, x1 = end[i] - start[i] + mar, y1 = fl[1]+fl[2]/6, code = 3, 
-    col = "red", lty = "solid", lwd = 2, angle = 60)        
-      
-    text(x = mar - (snrmar * 0.5), y = fl[1]+fl[2]/4, labels = "Noise", col = "red",pos = 3)
-      
-    text(x = end[i] - start[i] + mar + (snrmar * 0.5), y = fl[1]+fl[2]/4, labels = "Noise", col = "red",pos = 3)  
-    }
-
     dev.off()  
     return (NULL)
     
