@@ -2,7 +2,7 @@
 #'
 #' \code{specan} measures 22 acoustic parameters on acoustic signals for which the start and end times 
 #' are provided. 
-#' @usage specan(X, bp = c(0,22), wl = 512, threshold = 15, parallel = FALSE)
+#' @usage specan(X, bp = c(0,22), wl = 512, threshold = 15, parallel = 1)
 #' @param X data frame with the following columns: 1) "sound.files": name of the .wav 
 #' files, 2) "sel": number of the selections, 3) "start": start time of selections, 4) "end": 
 #' end time of selections. The ouptut of \code{\link{manualoc}} or \code{\link{autodetec}} can 
@@ -12,9 +12,9 @@
 #' @param wl A numeric vector of length 1 specifying the spectrogram window length. Default is 512.
 #' @param threshold amplitude threshold (\%) for fundamental frequency and 
 #'   dominant frequency detection. Default is 15.
-#' @param parallel Either logical or numeric. Controls wehther parallel computing is applied.
-#'  If \code{TRUE} 2 cores are employed. If numeric, it specifies the number of cores to be used. 
-#'  Not available for windows OS. 
+#' @param parallel Numeric. Controls whether parallel computing is applied.
+#' It specifies the number of cores to be used. Default is 1 (e.i. no parallel computing).
+#' For windows OS the \code{warbleR} from github to run parallel. 
 #' @return Data frame with the following acoustic parameters: 
 #' \itemize{
 #'    \item \code{duration}: length of signal
@@ -72,9 +72,9 @@
 #' # remove example directory
 #' unlink(getwd(), recursive = TRUE)
 #' }
-#' @author Marcelo Araya-Salas (\url{http://marceloarayasalas.weebly.com/}), Grace Smith Vidaurre and Hua Zhong
+#' @author Marcelo Araya-Salas (\email{araya-salas@@cornell.edu}), Grace Smith Vidaurre and Hua Zhong
 
-specan <- function(X, bp = c(0,22), wl = 512, threshold = 15, parallel = FALSE){
+specan <- function(X, bp = c(0,22), wl = 512, threshold = 15, parallel = 1){
   if(class(X) == "data.frame") {if(all(c("sound.files", "selec", 
                                         "start", "end") %in% colnames(X))) 
   {
@@ -106,7 +106,7 @@ specan <- function(X, bp = c(0,22), wl = 512, threshold = 15, parallel = FALSE){
   #return warning if not all sound files were found
   fs <- list.files(path = getwd(), pattern = ".wav$", ignore.case = TRUE)
   if(length(unique(sound.files[(sound.files %in% fs)])) != length(unique(sound.files))) 
-    message(paste(length(unique(sound.files))-length(unique(sound.files[(sound.files %in% fs)])), 
+    cat(paste(length(unique(sound.files))-length(unique(sound.files[(sound.files %in% fs)])), 
     ".wav file(s) not found"))
   
   #count number of sound files in working directory and if 0 stop
@@ -119,13 +119,23 @@ specan <- function(X, bp = c(0,22), wl = 512, threshold = 15, parallel = FALSE){
     selec <- selec[d]
     sound.files <- sound.files[d]
   }
-  #if parallel was called
-  if (parallel) {lapp <- function(X, FUN) parallel::mclapply(X, 
-      FUN, mc.cores = 2)} else    
-        if(is.numeric(parallel)) lapp <- function(X, FUN) parallel::mclapply(X, 
-              FUN, mc.cores = parallel) else lapp <- pbapply::pblapply
+
+  # If parallel is not numeric
+  if(!is.numeric(parallel)) stop("'parallel' must be a numeric vector of length 1") 
+  if(any(!(parallel %% 1 == 0),parallel < 1)) stop("'parallel' should be a positive integer")
   
-if(!parallel) message("Measuring acoustic parameters:")
+  # If parallel was called
+  if(parallel > 1)
+  { options(warn = -1)
+     
+       
+        if(Sys.info()[1] == "Windows"){ 
+          cat 
+          lapp <- pbapply::pblapply} else lapp <- function(X, FUN) parallel::mclapply(X, FUN, mc.cores = parallel)} else lapp <- pbapply::pblapply
+  
+  options(warn = 0)
+  
+if(parallel == 1) cat("Measuring acoustic parameters:")
 x <- as.data.frame(lapp(1:length(start), function(i) { 
   r <- tuneR::readWave(file.path(getwd(), sound.files[i]), from = start[i], to = end[i], units = "seconds") 
  
