@@ -5,6 +5,6 @@
 # see https://github.com/hadley/r-pkgs/blob/master/r.rmd
 
 .onAttach <- function(libname, pkgname) {
-  packageStartupMessage("\nNOTE: install ggplot2 to run coor.graph()")
+  packageStartupMessage("\nNOTE: 1. install 'ggplot2' to run coor.graph()")
+  packageStartupMessage("2. install 'warbleR' from github to run parallel computing in windows OS")
 }
-
